==> puppet-module-barbican_17.4.0.orig.tar.xz: puppet-module-barbican-17.4.0/spec/classes/barbican_plugins_simple_crypto_spec.rb <==
#
# Copyright (C) 2016 Red Hat Inc. <licensing@redhat.com>
#
# Author: Ade Lee <alee@redhat.com>
#
# Licensed under the Apache License, Version 2.0 (the "License"); you may
# not use this file except in compliance with the License. You may obtain
# a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
# WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
# License for the specific language governing permissions and limitations
# under the License.
#
# Unit tests for barbican::plugins::simple_crypto class
#
require 'spec_helper'

describe 'barbican::plugins::simple_crypto' do

  shared_examples_for 'barbican plugins simple_crypto' do
    describe 'with parameter passed into pk11 plugin' do
      let :params do
        {
          :simple_crypto_plugin_kek       => 'XXXXXXXXXXXXX',
          :global_default                 => true,
        }
      end

      it 'is_expected.to set simple_crypto parameters' do
        is_expected.to contain_barbican_config('simple_crypto_plugin/kek') \
          .with_value(params[:simple_crypto_plugin_kek])
        is_expected.to contain_barbican_config(
          'secretstore:simple_crypto/secret_store_plugin') \
          .with_value('store_crypto')
        is_expected.to contain_barbican_config(
          'secretstore:simple_crypto/crypto_plugin') \
          .with_value('simple_crypto')
        is_expected.to contain_barbican_config(
          'secretstore:simple_crypto/global_default') \
          .with_value('true')
      end
    end

    describe 'with no parameter passed into pk11 plugin' do
      let :params do
        {}
      end

      it 'is_expected.to set default simple_crypto parameters' do
        is_expected.to contain_barbican_config('simple_crypto_plugin/kek') \
          .with_value('<SERVICE DEFAULT>')
        is_expected.to contain_barbican_config(
          'secretstore:simple_crypto/secret_store_plugin') \
          .with_value('store_crypto')
        is_expected.to contain_barbican_config(
          'secretstore:simple_crypto/crypto_plugin') \
          .with_value('simple_crypto')
        is_expected.to contain_barbican_config(
          'secretstore:simple_crypto/global_default') \
          .with_value('false')
      end
    end
  end

  on_supported_os({
    :supported_os   => OSDefaults.get_supported_os
  }).each do |os,facts|
    context "on #{os}" do
      let (:facts) do
        facts.merge(OSDefaults.get_facts({
          :processorcount => 8,
          :fqdn           => 'some.host.tld',
          :concat_basedir => '/var/lib/puppet/concat',
        }))
      end

      it_configures 'barbican plugins simple_crypto'
    end
  end
end

==> puppet-module-barbican_21.0.0.orig.tar.xz: puppet-module-barbican-21.0.0/spec/classes/barbican_plugins_simple_crypto_spec.rb <==
#
# Copyright (C) 2016 Red Hat Inc. <licensing@redhat.com>
#
# Author: Ade Lee <alee@redhat.com>
#
# Licensed under the Apache License, Version 2.0 (the "License"); you may
# not use this file except in compliance with the License. You may obtain
# a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
# WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
# License for the specific language governing permissions and limitations
# under the License.
#
# Unit tests for barbican::plugins::simple_crypto class
#
require 'spec_helper'

describe 'barbican::plugins::simple_crypto' do

  shared_examples_for 'barbican plugins simple_crypto' do
    describe 'with parameter passed into pk11 plugin' do
      let :params do
        {
          :simple_crypto_plugin_kek => 'XXXXXXXXXXXXX',
          :global_default           => true,
        }
      end

      it 'is_expected.to set simple_crypto parameters' do
        is_expected.to contain_barbican_config('simple_crypto_plugin/kek') \
          .with_value(params[:simple_crypto_plugin_kek]) \
          .with_secret(true)
        is_expected.to contain_barbican_config(
          'secretstore:simple_crypto/secret_store_plugin') \
          .with_value('store_crypto')
        is_expected.to contain_barbican_config(
          'secretstore:simple_crypto/crypto_plugin') \
          .with_value('simple_crypto')
        is_expected.to contain_barbican_config(
          'secretstore:simple_crypto/global_default') \
          .with_value('true')
      end
    end

    describe 'with no parameter passed into pk11 plugin' do
      let :params do
        {}
      end

      it 'is_expected.to set default simple_crypto parameters' do
        is_expected.to contain_barbican_config('simple_crypto_plugin/kek') \
          .with_value('<SERVICE DEFAULT>') \
          .with_secret(true)
        is_expected.to contain_barbican_config(
          'secretstore:simple_crypto/secret_store_plugin') \
          .with_value('store_crypto')
        is_expected.to contain_barbican_config(
          'secretstore:simple_crypto/crypto_plugin') \
          .with_value('simple_crypto')
        is_expected.to contain_barbican_config(
          'secretstore:simple_crypto/global_default') \
          .with_value('false')
      end
    end
  end

  on_supported_os({
    :supported_os   => OSDefaults.get_supported_os
  }).each do |os,facts|
    context "on #{os}" do
      let (:facts) do
        facts.merge(OSDefaults.get_facts({
          :processorcount => 8,
          :fqdn           => 'some.host.tld',
          :concat_basedir => '/var/lib/puppet/concat',
        }))
      end

      it_configures 'barbican plugins simple_crypto'
    end
  end
end
